@@ -32,7 +32,7 @@ class Brain(Services.Service):
 	Service for authorization, sign in, sign up, permissions etc.
 	"""
 
-	def _create_Key(self, user, type_):
+	def _create_key(self, user, type_):
 		"""Create Key
 
 		Creates a key used for verification of the user
@@ -495,6 +495,13 @@ class Brain(Services.Service):
 		# Pop off the URL
 		sURL = req['body'].pop('url')
 
+		# Strip leading and trailing spaces on the email
+		req['body']['email'] = req['body']['email'].strip()
+
+		# Make sure the email is valid structurally
+		if not body.regex.EMAIL_ADDRESS.match(req['body']['email']):
+			return Services.Error(body.errors.BODY_FIELD, [['email', 'invalid']])
+
 		# Check if a user with that email already exists
 		sExistingUserID = User.exists(req['body']['email'], 'email')
 		if sExistingUserID:
@@ -519,11 +526,18 @@ class Brain(Services.Service):
 		# Create the record
 		sID = oUser.create(changes={'user': req['session'] and req['session']['user']['_id'] or body.users.SYSTEM_USER_ID})
 
+		# Create empty permissions
+		oPermissions = Permissions({
+			'_user': sID,
+			'rights': {}
+		})
+		oPermissions.create(changes={'user': req['session'] and req['session']['user']['_id'] or body.users.SYSTEM_USER_ID})
+
 		# If the record was created
 		if sID:
 
 			# Create key for setup validation
-			sSetupKey = self._create_Key(oUser['_id'], 'setup')
+			sSetupKey = self._create_key(oUser['_id'], 'setup')
 
 			# Email the user the setup link
 			oResponse = Services.create('mouth', 'email', {'body': {
@@ -620,6 +634,16 @@ class Brain(Services.Service):
 			try: del req['body'][k]
 			except KeyError: pass
 
+		# If the email was passed
+		if 'email' in req['body']:
+
+			# Strip leading and trailing spaces
+			req['body']['email'] = req['body']['email'].strip()
+
+			# Make sure it's valid structurally
+			if not body.regex.EMAIL_ADDRESS.match(req['body']['email']):
+				return Services.Error(body.errors.BODY_FIELD, [['email', 'invalid']])
+
 		# Step through each field passed and update/validate it
 		lErrors = []
 		for f in req['body']:
@@ -673,6 +697,9 @@ class Brain(Services.Service):
 		if oUser['email'] == req['body']['email']:
 			return Services.Response(False)
 
+		# Strip leading and trailing spaces on email
+		req['body']['email'] = req['body']['email'].strip()
+
 		# Make sure the email is valid structurally
 		if not body.regex.EMAIL_ADDRESS.match(req['body']['email']):
 			return Services.Error(body.errors.BODY_FIELD, [['email', 'invalid']])
@@ -702,7 +729,7 @@ class Brain(Services.Service):
 			User.clear(oUser['_id'])
 
 			# Create key
-			sKey = self._creat_key(oUser['_id'], 'verify')
+			sKey = self._create_key(oUser['_id'], 'verify')
 
 			# Verification template variables
 			dTpl = {
